@@ -2,12 +2,13 @@ from enum import Enum
 from typing import List, Optional
 
 from pydantic import BaseModel as PydanticBaseModel
+from pydantic import Field
 from pydantic.class_validators import validator
 
 LOGGER_LEVEL = ["DEBUG", "INFO", "WARNING", "ERROR", "FATAL", "CRITICAL"]
 
 
-class ReaderType(str, Enum):
+class MeterType(str, Enum):
     LGE450 = "lge450"
 
 
@@ -23,8 +24,8 @@ class BaseModel(PydanticBaseModel):
         use_enum_values = True
 
 
-class ReaderDto(BaseModel):
-    type: ReaderType
+class MeterDto(BaseModel):
+    type: MeterType
     port: str
     key: Optional[str]
 
@@ -37,7 +38,7 @@ class ReaderDto(BaseModel):
 
 
 class MqttSinkDto(BaseModel):
-    type = SinkType.MQTT
+    type = Field(SinkType.MQTT, const=True)
     host: str
     port: int = 1883
     tls: bool = False
@@ -69,7 +70,7 @@ class MqttSinkDto(BaseModel):
 
 
 class LoggerSinkDto(BaseModel):
-    type = SinkType.LOGGER
+    type = Field(SinkType.LOGGER, const=True)
     name: str = "DataLogger"
 
     @validator("name")
@@ -82,7 +83,7 @@ class LoggerSinkDto(BaseModel):
 
 class ConfigDto(BaseModel):
     log_level: str = "WARNING"
-    readers: List[ReaderDto] = []
+    meters: List[MeterDto] = []
     mqtt_sink: Optional[MqttSinkDto]
     logger_sink: Optional[LoggerSinkDto]
 
